Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(88)

Unified Diff: ash/wm/window_resizer.h

Issue 11369017: Use correct restore bounds in resizer. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 8 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ash/wm/window_resizer.h
diff --git a/ash/wm/window_resizer.h b/ash/wm/window_resizer.h
index f393af600fd055f8f5d0932c1d5441c33727f725..ce681927b160ddebb9299b2edd2217a5884f8a1d 100644
--- a/ash/wm/window_resizer.h
+++ b/ash/wm/window_resizer.h
@@ -62,7 +62,10 @@ class ASH_EXPORT WindowResizer {
// The window we're resizing.
aura::Window* window;
- // Initial bounds of the window.
+ // Initial bounds of the window in parent coordinates.
+ gfx::Rect initial_bounds_in_parent;
+
+ // Initial bounds of the window in screen coordinates.
gfx::Rect initial_bounds;
sky 2012/11/01 16:34:35 How come we need to track both bounds in parent an
oshima 2012/11/01 18:11:35 I originally thought it's more readable, but it wa
// Restore bounds (in screen coordinates) of the window before the drag

Powered by Google App Engine
This is Rietveld 408576698